# Changelog

## [2.0.0] - 2020-12-07
### Added
- Contains **version 2020a** of CommonRoad vehicle models
- Kinematic single-track model with on-axle trailer (truck model) was added
- Additional vehicle parameter set for a semi trailer truck was added (vehicle ID:4)
- A nonlinear single-track model with Pacejka tire forces was added (single-track drift model)

## Changed
- When switching from more complex models to the kinematic single-track model at low velocities, the correct reference point is now considered

### Fixed
- minor refactoring and restructuring


## [1.0.0] - 2020-07-20
### Added
- Contains **version 2019b** of CommonRoad vehicle models
- Initial release of Pypi vehicle models package

